==> fujicoin-22.0.1.tar.gz: fujicoin-22.0.1/src/qt/locale/fujicoin_mr_IN.ts <==
<TS version="2.1" language="mr_IN">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">पत्ता किंवा लेबल संपादित करण्यासाठी उजवे बटण क्लिक करा.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>एक नवीन पत्ता तयार करा</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;नवा</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>सध्याचा निवडलेला पत्ता सिस्टीम क्लिपबोर्डावर कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;कॉपी</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;बंद करा</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>सध्याचा निवडलेला पत्ता यादीमधून काढून टाका</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">शोधण्यासाठी पत्ता किंवा लेबल दाखल करा</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;काढून टाका</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी पाठवायची आहेत तो निवडा</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी प्राप्त करायची आहेत तो</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;निवडा</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">प्रेषक पत्ते</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">स्वीकृती पत्ते</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">पैसे पाठविण्यासाठीचे हे तुमचे बिटकॉईन पत्त्ते आहेत. नाणी पाठविण्यापूर्वी नेहमी रक्कम आणि प्राप्त होणारा पत्ता तपासून पहा.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;पत्ता कॉपी करा</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">शिक्का कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;संपादित</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">पत्त्याची निर्यात करा</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">पत्ता</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    </context>
</TS>

==> fujicoin-23.0.tar.gz: fujicoin-23.0/src/qt/locale/fujicoin_mr_IN.ts <==
<TS version="2.1" language="mr_IN">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">पत्ता किंवा लेबल संपादित करण्यासाठी उजवे बटण क्लिक करा.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">एक नवीन पत्ता तयार करा</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;नवा</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता सिस्टीम क्लिपबोर्डावर कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;कॉपी</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;बंद करा</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">सध्याचा निवडलेला पत्ता यादीमधून काढून टाका</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">शोधण्यासाठी पत्ता किंवा लेबल दाखल करा</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;काढून टाका</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी पाठवायची आहेत तो निवडा</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ज्या पत्त्यावर नाणी प्राप्त करायची आहेत तो</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;निवडा</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">प्रेषक पत्ते</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">स्वीकृती पत्ते</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">पैसे पाठविण्यासाठीचे हे तुमचे बिटकॉईन पत्त्ते आहेत. नाणी पाठविण्यापूर्वी नेहमी रक्कम आणि प्राप्त होणारा पत्ता तपासून पहा.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;पत्ता कॉपी करा</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">शिक्का कॉपी करा</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;संपादित</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">पत्त्याची निर्यात करा</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Fujicoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">पत्ता</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(लेबल नाही)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">पत्ता</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">निर्यात अयशस्वी</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;एक्स्पोर्ट</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">सध्याच्या टॅबमधील डेटा एका फाईलमध्ये एक्स्पोर्ट करा</translation>
    </message>
    </context>
</TS>
